@@ -8,11 +8,20 @@ TF_CPP_MIN_LOG_LEVEL 取值 3 ： 屏蔽通知信息、警告信息和报错信
 '''
 import tensorflow as tf
 
+import GPUtil
+
 info='this is a test for GPU'
 
-def gpu():
+def info():
     tf_version=tf.__version__
     gpu=tf.config.list_physical_devices('GPU')
-    return f'TensorFlow:{tf_version}\nGPU nummber:{len(gpu)}\nGPU Info:{gpu}'
+    cpu=tf.config.list_physical_devices('CPU')
+    GPUtil.showUtilization()
+    return f'TensorFlow:{tf_version}\n' \
+           f'CPU nummber:{len(cpu)}\n' \
+           f'CPU Info:{cpu}\n' \
+           f'GPU nummber:{len(gpu)}\n' \
+           f'GPU Info:{gpu}'
 
 
+print(info())
\ No newline at end of file
